@@ -233,16 +233,38 @@ class MongoDBConnection():
         return MongoDBCursor(self.client, self.database)
 
 
-
-def connect(uri:str)->MongoDBConnection:
+def connect(**kwargs)->MongoDBConnection:
     """Connect to MongoDB
     :param uri: MongoDB URI (e.g. mongodb://user:password@localhost:27017/db)
+    :param host: MongoDB host (e.g. localhost)
+    :param port: MongoDB port (e.g. 27017)
+    :parm username: MongoDB user name (e.g. user)
+    :param password: MongoDB password (e.g. password)
+    :param database: MongoDB database (e.g. db)
     :return: MongoDBConnection
     """
-    match = re.match(r'^mongodb://((?P<user>.*):(?P<password>.*)@)?(?P<host>.*?)(:(?P<port>[1-9][0-9]*))?/(?P<database>.*)$', uri)
-    d = match.groupdict()
-    return MongoDBConnection(d["host"], int(d["port"]), d["user"], d["password"], d["database"])
+    if "uri" in kwargs:
+        uri = kwargs["uri"]
+        match = re.match(r'^mongodb://((?P<user>.*):(?P<password>.*)@)?(?P<host>.*?)(:(?P<port>[1-9][0-9]*))?/(?P<database>.*)$', uri)
+        d = match.groupdict()
+        return MongoDBConnection(d["host"], int(d["port"]), d["user"], d["password"], d["database"])
+    else:
+        if "username" not in kwargs:
+            kwargs["username"] = None
 
+        if "password" not in kwargs:
+            kwargs["password"] = None
+        
+        if "host" not in kwargs:
+            kwargs["host"] = "localhost"
+        
+        if "port" not in kwargs:
+            kwargs["port"] = 27017
+        
+        if "database" not in kwargs:
+            kwargs["database"] = "testdb"
+
+        return MongoDBConnection(kwargs["host"], int(kwargs["port"]), kwargs["username"], kwargs["password"], kwargs["database"])
 
 
 apilevel = 2.0
